summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchkeyboard.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-04 02:22:38 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-04 02:22:38 +0000
commit98a12d05a48814bec3870b9a6d5865475cfa1c95 (patch)
treea711801e47696fb0cf162abd7330e0b5b480ba39 /ktouch/src/ktouchkeyboard.h
parent421a1845137c7c396b5d03bce53237fcb149d602 (diff)
downloadtdeedu-98a12d05a48814bec3870b9a6d5865475cfa1c95.tar.gz
tdeedu-98a12d05a48814bec3870b9a6d5865475cfa1c95.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1211429 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ktouch/src/ktouchkeyboard.h')
-rw-r--r--ktouch/src/ktouchkeyboard.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ktouch/src/ktouchkeyboard.h b/ktouch/src/ktouchkeyboard.h
index 5334c49b..fd2613fe 100644
--- a/ktouch/src/ktouchkeyboard.h
+++ b/ktouch/src/ktouchkeyboard.h
@@ -24,7 +24,7 @@
class KURL;
/// This class stores the keyboard layout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
public:
@@ -32,7 +32,7 @@ class KTouchKeyboard {
KTouchKeyboard() { createDefault(); }
/// Clears the keyboard (resets all data)
void clear();
/// Loads a keyboard layout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).
bool loadXML(TQWidget * window, const KURL& url);
@@ -47,7 +47,7 @@ class KTouchKeyboard {
TQValueVector<KTouchKeyConnector> m_connectors; ///< Vector with connectivity data.
QString m_title; ///< Title of the keyboard (to appear in the menu).
- QString m_comment; ///< Comments about the creator of the keyboard layout.
+ QString m_comment; ///< Comments about the creator of the keyboard tqlayout.
QString m_language; ///< Language ID of keyboard
QString m_fontSuggestions; ///< Suggestions of fonts to be used on the keys.
@@ -24,7 +24,7 @@
class KURL;
-/// This class stores the keyboard layout and the connectivity between characters
+/// This class stores the keyboard tqlayout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
@@ -32,7 +32,7 @@ class KTouchKeyboard {
/// Clears the keyboard (resets all data)
void clear();
- /// Loads a keyboard layout (old format) from file (returns true if successful).
+ /// Loads a keyboard tqlayout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).